powered by
This function reads a Matrix Market file and converts it to a matrix in R.
fmm_to_mat(filename)
A matrix containing the data read from the Matrix Market file.
The name of the input Matrix Market file to be read.
# Create sample_mat <- matrix(c(1, 2, 3, 4), nrow = 2) temp_file_mat <- tempfile(fileext = ".mtx") write_fmm(sample_mat, temp_file_mat) # Read mat <- fmm_to_mat(temp_file_mat)
Run the code above in your browser using DataLab