powered by
This function takes a numeric matrix and converts it into a Matrix Market file.
A boolean indicating success or failure. Writes a MTX file to disk.
A numeric matrix to be converted.
The name of the output file where the Matrix Market formatted data will be saved.
intmat <- matrix(c(1L, 2L, 3L, 4L), nrow = 2) intmat_to_fmm(intmat, tempfile(fileext = ".mtx"))
Run the code above in your browser using DataLab