Learn R Programming

fastMatMR (version 1.2.5)

intvec_to_fmm: Convert a numeric integer vector to Matrix Market Format

Description

This function takes a numeric intvector and converts it into a Matrix Market output file.

Value

A boolean indicating success or failure. Writes a MTX file to disk.

Arguments

input

A numeric integer vector to be converted.

filename

The name of the output file where the Matrix Market formatted data will be saved.

Examples

Run this code
intvec <- c(1L, 2L, 3L)
intvec_to_fmm(intvec, tempfile(fileext = ".mtx"))

Run the code above in your browser using DataLab