Learn R Programming

fastMatMR (version 1.2.5)

mat_to_fmm: Convert a Numeric Matrix to Matrix Market Format

Description

This function takes a numeric matrix and converts it into a Matrix Market file.

Value

A boolean indicating success or failure. Writes a MTX file to disk.

Arguments

input

A numeric matrix to be converted.

filename

The name of the output file where the Matrix Market formatted data will be saved.

Examples

Run this code
mat <- matrix(c(1, 2, 3, 4), nrow = 2)
mat_to_fmm(mat, tempfile(fileext = ".mtx"))

Run the code above in your browser using DataLab