powered by
This function takes a numeric intvector and converts it into a Matrix Market output file.
A boolean indicating success or failure. Writes a MTX file to disk.
A numeric integer vector to be converted.
The name of the output file where the Matrix Market formatted data will be saved.
intvec <- c(1L, 2L, 3L) intvec_to_fmm(intvec, tempfile(fileext = ".mtx"))
Run the code above in your browser using DataLab