powered by
This function takes a numeric matrix and converts it into a Matrix Market file.
A boolean indicating success or failure. Writes a MTX file to disk.
A numeric matrix to be converted.
The name of the output file where the Matrix Market formatted data will be saved.
mat <- matrix(c(1, 2, 3, 4), nrow = 2) mat_to_fmm(mat, tempfile(fileext = ".mtx"))
Run the code above in your browser using DataLab